const path = require('path')
const ora = require('ora')
const { chalk, getPackageManager, logger, runCommand } = require('../../utils')
const { getPackageName } = require('../../utils/get-package')

/**
 * 打包
 * @param {String} execPath 要打包的目录
 */
function pack(execPath) {
  return new Promise((resolve, reject) => {
    const packageManager = getPackageManager()

    const spinner = ora(chalk.cyan('正在打包... \n')).start()

    runCommand(packageManager, ['pack', execPath], { cwd: path.dirname(execPath) }).then(() => {
      spinner.succeed(chalk.green('打包成功 \n'))

      const pkg = getPackageName(execPath)
      logger.log(`已生成组件包 ${chalk.magenta(pkg)} \n`)

      // callback && callback(null, pkg)
      resolve(pkg)
    }).catch(err => {
      spinner.fail(chalk.red('打包失败 \n'))
      logger.error(err)
      // callback && callback(err)
      reject(err)
    })
  })
}

module.exports = pack
