#!/usr/bin/env node

const { program } = require('commander')
const init = require('./init')
const create = require('./create')
const build = require('./build/index')
const serve = require('./serve')
const publish = require('./publish')
const docs = require('./docs')
const integrate = require('./integrate')
const pckJson = require('../package.json')

const { chalk } = require('../utils')

// 修改帮助信息的首行提示
program.name('pcsp').usage('[command] [options]')

// 版本管理
program.version(pckJson.version)

// 关闭默认的帮助子命令
program.addHelpCommand(false)

// 初始化组件工程命令
program
  .command('init')
  .description('初始化组件开发环境')
  .argument('[path]', '初始化路径')
  .action(path => {
    init(path)
  })

// 创建组件命令
program
  .command('create')
  .description('创建组件')
  .argument('<componentname>', '组件名称')
  .option('--path <path>', '指定路径')
  .action((componentname, options) => {
    create(componentname, options)
  })

// 编译构建命令
program
  .command('build')
  .description('编译构建')
  .argument('<source>', '目标文件')
  .argument('[destination]', '输出目录')
  .option('--analyzer', '分析模式')
  .option('--zip', '打包为zip格式')
  .option('--name <name>', '自定义名称')
  .option('--config <file>', '配置文件')
  .action((source, destination, options) => {
    build(source, destination, options)
  })

// 开发调试命令
program
  .command('serve')
  .description('启动开发模式')
  .argument('[source]', '目标文件')
  .option('--host <host>', 'IP地址', '0.0.0.0')
  .option('--port <port>', '端口', 8090)
  .option('--config <file>', '配置文件')
  .action((source, options) => {
    serve(source, options)
  })

// 发布命令
program
  .command('publish')
  .description('发布组件')
  .argument('[target]', '指定文件')
  .option('--username <username>', '配置用户名')
  .option('--password <password>', '配置密码')
  .option('--registry <registry>', '注册地址')
  .action((target, options) => {
    publish(target, options)
  })

// 生成文档命令
program
  .command('docs')
  .description('生成文档')
  .argument('<source>', '目标文件')
  .option('--config <file>', '配置文件')
  .action((source, options) => {
    docs(source, options)
  })

// 完整命令
program
  .command('integrate')
  .description('文档&编译&发布')
  .argument('<source>', '目标文件')
  .argument('[destination]', '输出目录')
  .option('--registry <registry>', '注册地址')
  .option('--zip', '打包为zip格式')
  .action((source, destination, options) => {
    integrate(source, destination, options)
  })

// 给help增加其它内容
program.on('--help', function () {
  // 前后两个空行调整格式，更舒适
  console.log(
    `\n运行 ${chalk.cyan(
      'pcsp <command> --help'
    )} 查看指令具体用法.\n`
  )
})

// 解析指令参数
program.parse(process.argv)
