const fs = require('fs')
const path = require('path')
const ora = require('ora')
const exec = require('child_process').exec

const utils = require('../utils')
const downloadTemplate = require('../lib/get-template')

/**
 * 拷贝文件到指定目录
 * @param {String} to 指定目录
 * @param {String} to 指定目录
 */
function copySync(from, to) {
  if (fs.existsSync(from)) {
    const stat = fs.lstatSync(from)

    if (stat.isDirectory()) {
      try {
        fs.statSync(to)
      } catch (err) {
        if (err.code === 'ENOENT') {
          fs.mkdirSync(to, { recursive: true })
        } else {
          throw err
        }
      }

      const files = fs.readdirSync(from)
      files.forEach((file) => {
        copySync(path.join(from, file), path.join(to, file))
      })
    } else if (stat.isFile()) {
      fs.writeFileSync(to, fs.readFileSync(from, 'binary'), 'binary')
    } else {
      throw new Error('stats invalid: ' + from)
    }
  }
}

/**
 * 通过内置模板初始化环境
 * @param to 目标路径
 */
function builtInTemplate(to, spinner) {
  try {
    const from = utils.resolveDirname('template')
    copySync(from, to)

    spinner.succeed(utils.chalk.green('开发环境初始化完成 \n'))
  } catch (err) {
    spinner.fail(utils.chalk.red(`开发环境初始化失败：${err} \n`))
  }
}

/**
 * 初始化组件开发环境
 * @param dir 路径
 */
module.exports = function (dir) {
  dir = dir || '.'

  const spinner = ora(utils.chalk.cyan('开发环境初始化... \n')).start()

  const folder = utils.resolveCwd(dir)

  if (!fs.existsSync(folder)) {
    fs.mkdirSync(folder)
  }

  exec(`curl -I http://192.168.10.185:8081/public-lib/cli-template.git`, (error) => {
    if (error) {
      builtInTemplate(folder, spinner)
    } else {
      downloadTemplate(dir).then(() => {
        spinner.succeed(utils.chalk.green('开发环境初始化完成 \n'))
      }).catch(() => {
        builtInTemplate(folder, spinner)
      })
    }
  })
}
