const fs = require('fs')
const path = require('path')
const { chalk, getPackageManager, logger, resolveCwd, runCommand } = require('../utils')

const packageManager = getPackageManager()
const defaultRegistry = 'http://192.168.10.220:8085/nexus/repository/npm-snapshots'

/**
 * 用户登录
 * @param {Object} options 配置项
 */
function login(options) {
  return new Promise((resolve, reject) => {
    const registry = options.registry || defaultRegistry

    logger.log(`准备发布到仓库 ${chalk.cyan(registry)} \n`)

    runCommand(packageManager, ['login', `--registry=${registry}`]).then(() => {
      resolve()
    }).catch((err) => {
      reject(err)
    })
  })
}

/**
 * 上传组件包
 * @param {String} target 指定组件
 * @param {Object} options 配置项
 */
function upload(target, options) {
  if (target) {
    run(resolveCwd(target), options)
  } else {
    const output = resolveCwd('dist')

    fs.readdir(output, (err, files) => {
      err && logger.error(err)

      files.forEach((filename) => {
        const filepath = path.join(output, filename)
        const stat = fs.lstatSync(filepath)

        if (stat.isFile() && /\.tgz$/.test(filename)) {
          run(filepath, options)
        }
      })
    })
  }
}

/**
 * 运行
 * @param {String} filepath 指定组件
 * @param {Object} options 配置项
 */
function run(filepath, options) {
  const registry = options.registry || defaultRegistry
  runCommand(packageManager, ['publish', filepath, `--registry=${registry}`]).then(() => {
    logger.success('组件发布成功!')
  })
}

/**
 * 发布组件
 * @param {String} target 指定组件
 * @param {Object} options 配置项
 */
function publish(target, options = {}) {
  if (target && !fs.existsSync(resolveCwd(target))) {
    logger.error(`${target} 文件不存在!`)
    process.exit(2)
  }

  login(options).then(() => {
    upload(target, options)
  })
}

module.exports = publish
