const fs = require('fs')
const path = require('path')
const execa = require('execa')

function getPackageManager() {
  const hasLocalNpm = fs.existsSync(path.resolve(__dirname, 'package-lock.json'))

  if (hasLocalNpm) {
    return 'npm'
  }

  const hasLocalYarn = fs.existsSync(path.resolve(__dirname, 'yarn.lock'))

  if (hasLocalYarn) {
    return 'yarn'
  }

  const hasLocalPnpm = fs.existsSync(path.resolve(__dirname, 'pnpm-lock.yaml'))

  if (hasLocalPnpm) {
    return 'pnpm'
  }

  try {
    // the sync function below will fail if npm is not installed,
    // an error will be thrown
    if (execa.sync('npm', ['--version'])) {
      return 'npm'
    }
  } catch (e) {
    // Nothing
  }

  try {
    // the sync function below will fail if yarn is not installed,
    // an error will be thrown
    if (execa.sync('yarn', ['--version'])) {
      return 'yarn'
    }
  } catch (e) {
    // Nothing
  }

  try {
    // the sync function below will fail if pnpm is not installed,
    // an error will be thrown
    if (execa.sync('pnpm', ['--version'])) {
      return 'pnpm'
    }
  } catch (e) {
    process.exit(2)
  }
}

module.exports = getPackageManager
