const path = require('path')
const fs = require('fs')

function getPackageJson(projectPath) {
  const packagePath = path.join(projectPath, 'package.json')

  let packageJson
  try {
    packageJson = fs.readFileSync(packagePath, 'utf-8')
  } catch (err) {
    throw new Error(`路径 '${packagePath}' 不存在 package.json 文件`)
  }

  try {
    packageJson = JSON.parse(packageJson)
  } catch (err) {
    throw new Error('package.json 文件解析失败')
  }

  return packageJson
}

/**
 * 获取打包后的文件名
 * @param {String} dir 打包目录
 * @returns
 */
function getPackageName(dir, type = 'tgz') {
  try {
    const data = getPackageJson(dir)

    const filename = `${data.name}-${data.version}.${type}`.replace(/^@/, '').replace(/\//, '-')

    const tgz = path.join(path.dirname(dir), filename)

    return tgz
  } catch {
    return false
  }
}

module.exports = {
  getPackageJson,
  getPackageName
}
